dot

Macro dot 

macro_rules! dot {
    ($seq:expr) => { ... };
    ($node:expr, $seq:expr) => { ... };
    ($node:expr, $app:expr, $seq:expr) => { ... };
}
Convenience macro for creating dot values.

NOTE! This is mostly useful for tests, since it does not provide control over the app or priority fields of a dot.