DotFunMap

Struct DotFunMap 

pub struct DotFunMap<V> { /* private fields */ }
A map from Dot to V: DotStore, whose computed dots is the union of the dots of its values.

Quoth the DSON paper:

We combine the DotMap and DotFun to get a dot store which maps dots to dot stores. The join operation keeps keys that have not been deleted (as in the DotFun), or the values themselves haven’t been deleted (as in the DotMap).

Note that this is called CompDotFun in the DSON paper (section 5.1), but DotFunMap in their prototype implementation.

Implementations

Source

impl<V> DotFunMap<V>

pub fn with_capacity(capacity: usize) -> Self

Constructs a DotFunMap with the given initial capacity.

pub fn iter(&self) -> impl ExactSizeIterator<Item = (Dot, &V)>

Produces an iterator over the map’s keys and values.

pub fn keys(&self) -> impl ExactSizeIterator<Item = Dot> + '_

Produces an iterator over the map’s keys.

pub fn values(&self) -> impl ExactSizeIterator<Item = &V>

Produces an iterator over the map’s values.

pub fn len(&self) -> usize

Returns the number of keys in the map.

pub fn is_empty(&self) -> bool

Returns true if the map is empty.

Source

impl<V> DotFunMap<V>

pub fn get(&self, dot: &Dot) -> Option<&V>

Retrieves the associated value, if any, for the given Dot.

pub fn get_mut(&mut self, dot: &Dot) -> Option<&mut V>

Retrieves a mutable reference to the associated value, if any, for the given Dot.

pub fn has(&self, dot: &Dot) -> bool

Returns true if the given Dot has a value in this map.

pub fn set(&mut self, dot: Dot, value: V) -> Option<V>

Associates the value with the given Dot.

Returns the previous value if any.