pub struct DotFunMap<V> { /* private fields */ }Expand description
A map from Dot to V: DotStore, whose computed dots is the union of the dots of its
values.
Quoth the DSON paper:
We combine the
DotMapandDotFunto get a dot store which maps dots to dot stores. The join operation keeps keys that have not been deleted (as in theDotFun), or the values themselves haven’t been deleted (as in theDotMap).
Note that this is called CompDotFun in the DSON paper (section 5.1), but DotFunMap in their
prototype implementation.
Implementations
Sourceimpl<V> DotFunMap<V>
impl<V> DotFunMap<V>
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Constructs a DotFunMap with the given initial capacity.
Sourcepub fn iter(&self) -> impl ExactSizeIterator<Item = (Dot, &V)>
pub fn iter(&self) -> impl ExactSizeIterator<Item = (Dot, &V)>
Produces an iterator over the map’s keys and values.
Sourcepub fn keys(&self) -> impl ExactSizeIterator<Item = Dot> + '_
pub fn keys(&self) -> impl ExactSizeIterator<Item = Dot> + '_
Produces an iterator over the map’s keys.
Sourcepub fn values(&self) -> impl ExactSizeIterator<Item = &V>
pub fn values(&self) -> impl ExactSizeIterator<Item = &V>
Produces an iterator over the map’s values.